MODULE Device;
(* =========================================================================  
   Astrobe for Cortex-M3 Library Functions for device-specific features  
  
   Target:
     All supported LPC13xx / LPC17xx systems
     
   (c) 2012 CFB Software   
   http://www.astrobe.com  
 
 ========================================================================= *)

IMPORT IAP;

VAR 
  id: INTEGER;
  sectorCount*, name*: INTEGER;

PROCEDURE* Init(id: INTEGER; VAR name, sectorCount: INTEGER);
BEGIN
  IF id = 02C40102BH THEN
    name := 1313;  
    sectorCount := 7
  ELSIF id = 03D00002BH THEN 
    name := 1343;  
    sectorCount := 7
  ELSIF id = 025001118H THEN 
    name := 1751;  
    sectorCount := 7
  ELSIF id = 025001121H THEN 
    name := 1752;  
    sectorCount := 15
  ELSIF id = 025011722H THEN 
    name := 1754;  
    sectorCount := 17
  ELSIF id = 025011723H THEN 
    name := 1756;  
    sectorCount := 21
  ELSIF id = 025013F37H THEN 
    name := 1758;  
    sectorCount := 29
  ELSIF id = 025113737H THEN 
    name := 1759;  
    sectorCount := 29
  ELSIF id = 026012033H THEN 
    name := 1763;  
    sectorCount := 21
  ELSIF id = 026011922H THEN 
    name := 1764;  
    sectorCount := 17
  ELSIF id = 026013733H THEN 
    name := 1765;  
    sectorCount := 21
  ELSIF id = 026013F33H THEN 
    name := 1766;  
    sectorCount := 21
  ELSIF id = 026012837H THEN 
    name := 1767;  
    sectorCount := 29
  ELSIF id = 026013F37H THEN 
    name := 1768;  
    sectorCount := 29
  ELSIF id = 026113F37H THEN 
    name := 1769;  
    sectorCount := 29
  END 
END Init;


PROCEDURE* SectorStartAddr*(sectorNo: INTEGER): INTEGER;
(* Sectors 0..15 are 4KB, Sectors 16..29 are 32KB *)
VAR 
  addr: INTEGER;
BEGIN
  ASSERT(sectorNo >= 0, 20);
  ASSERT(sectorNo <= sectorCount, 21);
  IF sectorNo < 16 THEN 
    addr := 00001000H * sectorNo
  ELSE 
    addr := 00010000H + ((sectorNo - 16) * 08000H)
  END;
  RETURN addr
END SectorStartAddr;


PROCEDURE* SectorSize*(sectorNo: INTEGER): INTEGER;
(* Sectors 0..15 are 4KB, Sectors 16..29 are 32KB *)
VAR 
  nBytes: INTEGER;
BEGIN
  ASSERT(sectorNo >= 0, 20);
  ASSERT(sectorNo <= sectorCount, 21);
  IF sectorNo < 16 THEN 
    nBytes := 4 * 1024
  ELSE 
    nBytes := 32 * 1024
  END;
  RETURN nBytes
END SectorSize;
    
    
BEGIN
  IAP.ReadPartID(id); 
  Init(id, name, sectorCount)
END Device.
  
  
